@@ -1,6 +1,8 @@
 from .Constants import *
 from .Dates import *
+from .Debug import *
 from .Exceptions import *
+from .Files import *
 from .HID_BUFFER import *
 from .Json import *
 from .Logging import *
